pub(crate) struct DiagnosticCollection {
pub(crate) native_syntax: FxHashMap<FileId, (usize, Vec<Diagnostic>)>,
pub(crate) native_semantic: FxHashMap<FileId, (usize, Vec<Diagnostic>)>,
pub(crate) check: Vec<WorkspaceFlycheckDiagnostic>,
pub(crate) check_fixes: Arc<Vec<FxHashMap<Option<PackageSpecifier>, FxHashMap<FileId, Vec<Fix>>>>>,
changes: FxHashSet<FileId>,
generation: usize,
}Fields
native_syntax: FxHashMap<FileId, (usize, Vec<Diagnostic>)>native_semantic: FxHashMap<FileId, (usize, Vec<Diagnostic>)>check: Vec<WorkspaceFlycheckDiagnostic>check_fixes: Arc<Vec<FxHashMap<Option<PackageSpecifier>, FxHashMap<FileId, Vec<Fix>>>>>changes: FxHashSet<FileId>generation: usizeCounter for supplying a new generation number for diagnostics. This is used to keep track of when to clear the diagnostics for a given file as we compute diagnostics on multiple worker threads simultaneously which may result in multiple diagnostics updates for the same file in a single generation update (due to macros affecting multiple files).
Implementations
Sourceimpl DiagnosticCollection
impl DiagnosticCollection
pub(crate) fn clear_check(&mut self, flycheck_id: usize)
pub(crate) fn clear_check_all(&mut self)
pub(crate) fn clear_check_for_package( &mut self, flycheck_id: usize, package_id: PackageSpecifier, )
pub(crate) fn clear_check_older_than( &mut self, flycheck_id: usize, generation: usize, )
pub(crate) fn clear_check_older_than_for_package( &mut self, flycheck_id: usize, package_id: PackageSpecifier, generation: usize, )
pub(crate) fn clear_native_for(&mut self, file_id: FileId)
pub(crate) fn add_check_diagnostic( &mut self, flycheck_id: usize, generation: usize, package_id: &Option<PackageSpecifier>, file_id: FileId, diagnostic: Diagnostic, fix: Option<Box<Fix>>, )
pub(crate) fn set_native_diagnostics(&mut self, kind: DiagnosticsTaskKind)
pub(crate) fn diagnostics_for( &self, file_id: FileId, ) -> impl Iterator<Item = &Diagnostic>
pub(crate) fn take_changes(&mut self) -> Option<FxHashSet<FileId>>
pub(crate) fn next_generation(&mut self) -> usize